==> ToolChain_STM32_1.0.50.tar.bz: ToolChain_STM32_1.0.50/ToolChain/install_24_TTC_Watchdog.sh <==
#!/bin/bash

#
#  Install script for Watchdog-Handling 
#  with ARM Cortex M3 core.
#
#  Script written by Gregor Rebel 2012
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="500_ttc_watchdogs"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------
  
  if [ ! -e OK.Install ]; then #{
    
    touch OK.Install
  fi #}
  if [ -e OK.Install ]; then #{
    Name="${INSTALLPATH}"
    createExtensionMakefileHead ${Name} #{
    File="../extensions/makefile.${Name}" 
    cat <<END_OF_MAKEFILE >>$File 

ifdef EXTENSION_200_cpu_stm32f10x
  INCLUDE_DIRS += -Icommon/cortexm3/
  vpath %.c common/cortexm3/
  MAIN_OBJS += stm32f10x_iwdg.o stm32_watchdog.o
endif
ifdef EXTENSION_200_cpu_stm32w1xx
  INCLUDE_DIRS += -Icommon/cortexm3/
  vpath %.c common/cortexm3/
  MAIN_OBJS += stm32f10x_iwdg.o em357_watchdog.o
endif


MAIN_OBJS += ttc_watchdog.o

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    File="../extensions/activate.${Name}.sh" #{
    createActivateScriptHead $File $0 "architecture independent support of hardware watchdogs"
    
    # create links into extensions.active/
    echo "createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET" >>$File
    
    createActivateScriptTail $File $Name
    #}

    echo "Installed successfully: $INSTALLPATH"
  fi #}
  cd ..
  rmdir 2>/dev/null $INSTALLPATH  # removes only empty install dir
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0

==> ToolChain_STM32_1.0.52.tar.bz: ToolChain_STM32_1.0.52/ToolChain/install_24_TTC_Watchdog.sh <==
#!/bin/bash

#
#  Install script for Watchdog-Handling 
#  with ARM Cortex M3 core.
#
#  Script written by Gregor Rebel 2012
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# openSuSE 12.1 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh
checkUserRoot "$1" "$2"

StartPath="`pwd`"
INSTALLPATH="500_ttc_watchdogs"
dir "$INSTALLPATH"
cd "$INSTALLPATH"

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------
  
  if [ ! -e OK.Install ]; then #{
    
    touch OK.Install
  fi #}
  if [ -e OK.Install ]; then #{
    Name="${INSTALLPATH}"
    createExtensionMakefileHead ${Name} #{
    File="../extensions/makefile.${Name}" 
    cat <<END_OF_MAKEFILE >>$File 

ifdef EXTENSION_200_cpu_stm32f10x
  INCLUDE_DIRS += -Icommon/cortexm3/
  vpath %.c common/cortexm3/
  MAIN_OBJS += stm32f10x_iwdg.o stm32_watchdog.o
endif
ifdef EXTENSION_200_cpu_stm32w1xx
  INCLUDE_DIRS += -Icommon/cortexm3/
  vpath %.c common/cortexm3/
  MAIN_OBJS += stm32f10x_iwdg.o em357_watchdog.o
endif


MAIN_OBJS += ttc_watchdog.o

END_OF_MAKEFILE
    createExtensionMakefileTail ${Name} #}
    createActivateScriptHead $Name ../extensions/ $0 "architecture independent support of hardware watchdogs" #{
    
    # create links into extensions.active/
    echo "createLink \$Dir_Extensions/makefile.$Name \$Dir_ExtensionsActive/makefile.$Name '' QUIET" >>$ActivateScriptFile
    
    createActivateScriptTail $Name ../extensions/
    #}

    echo "Installed successfully: $INSTALLPATH"
  fi #}
  cd ..
  rmdir 2>/dev/null $INSTALLPATH  # removes only empty install dir
#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

cd "$StartPath"
applyTargetUserAndGroup "$INSTALLPATH"

exit 0
